@@ -192,11 +192,21 @@ def merge_all_templates(params):
     print("Поиск и слияние завершено")
 
 
+def create_template(params):
+    """
+    Функция создания базового шаблона
+    """
+    __dump_json__(params.template_file, {"definitions": {}, "type": "object", "properties": {},
+                                         "required": [], "additionalProperties": False})
+    print("Конфигурация создана")
+
+
 methods = {
     "create": create_command,
     "update": update_command,
     "merge-template": merge_template,
-    "merge-all-templates": merge_all_templates
+    "merge-all-templates": merge_all_templates,
+    "create-template": create_template
 }
 
 
@@ -245,6 +255,11 @@ def create_parse():
     merge_all_template.add_argument("template_file")
     # endregion
 
+    # region create base template
+    create_template_parser = subparsers.add_parser("create-template", add_help=False)
+    create_template_parser.add_argument("template_file")
+    # endregion
+
     return parser
 
 
